<?php
/*
 *  Copyright notice
 *
 *  (c) 2006-2017 WEBFORMAT
 *
 *  All rights reserved
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

/**
 * Set of useful functions
 *
 */

require_once(t3lib_extMgm::extPath('wfqbe') . "lib/class.tx_wfqbe_api_xml2array.php");
require_once(t3lib_extMgm::extPath('wfqbe') . "lib/class.tx_wfqbe_utils.php");
require_once(t3lib_extMgm::extPath('wfqbe') . "lib/class.tx_wfqbe_connect.php");
require_once(t3lib_extMgm::extPath('wfqbe') . "pi1/class.tx_wfqbe_results.php");
require_once(t3lib_extMgm::extPath('wfqbe') . "tx_wfqbe_query_query/class.tx_wfqbe_queryform_generator.php");


class tx_wfqbe_api_query
{
    var $extKey = 'wfqbe';    // The extension key.

    var $piVars = array();
    var $query = '';
    var $connection = false;
    var $conf = array();
    var $cObj = '';


    /**
     * Function used to init the API
     * @param $query    The wfqbe record uid
     * @param $cObj        A cObj object
     * @param $piVars    The piVars array
     * @return boolean    Connection status
     */
    function init($query, $cObj = "", $piVars = "")
    {
        if (!t3lib_utility_Math::canBeInterpretedAsInteger($query))
            return false;

        $this->cObj = $cObj;
        if (!is_object($this->cObj)) {
            require_once(PATH_tslib . 'class.tslib_content.php');
            $this->cObj = $cObj = t3lib_div::makeInstance('tslib_cObj');
        }

        $result = false;
        if (is_array($piVars))
            $this->piVars = $piVars;
        else
            $this->piVars = t3lib_div::_GP('tx_wfqbe_pi1');

        // Finding the query record into the database
        $res = $GLOBALS['TYPO3_DB']->exec_SELECTquery('*', 'tx_wfqbe_query', 'uid=' . $query);
        if ($res !== false && $GLOBALS['TYPO3_DB']->sql_num_rows($res) == 1) {
            $this->query = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res);
            $this->loadTSConfig($this->query['pid']);
            $result = $this->connect();
        }

        return $result;
    }


    /**
     * Function used to connect to DB
     * @return boolean    Connection status
     */
    private function connect()
    {
        $where = 'tx_wfqbe_query.uid=' . intval($this->query['uid']) . ' AND ';

        // Create the connection to the remote DB
        $CONN = t3lib_div::makeInstance("tx_wfqbe_connect");
        $connection_obj = $CONN->connect($where);

        if ($connection_obj !== false) {
            $this->connection = $connection_obj["conn"];
            return true;
        }

        return false;
    }


    /**
     * Function used to execute the query
     * @return array    Rows
     */
    public function execQuery()
    {
        $rows = array();
        if (!$this->connection)
            return $rows;

        if ($this->query['type'] == "select") {
            // SELECT
            $SELECT = t3lib_div::makeInstance("tx_wfqbe_results");
            $SELECT->main($this->conf, $this->cObj, $this);
            $ris = $SELECT->getResultQuery($this->query, $this->connection);

            if ($ris === false || $ris->RecordCount() == 0) {
                // TODO: Print an error message

            } else {
                $rows = $ris->GetRows();
            }

        }

        return $rows;
    }


    /**
     * Retrieves the configuration (TS setup) of the page with the PID provided
     * as the parameter $pageId.
     */
    private function &loadTSConfig($pageId)
    {
        require_once(PATH_t3lib . 'class.t3lib_page.php');

        $template = t3lib_div::makeInstance('t3lib_TStemplate');
        // Disables the logging of time-performance information.
        $template->tt_track = 0;
        $template->init();

        // Gets the root line.
        $sys_page = t3lib_div::makeInstance('t3lib_pageSelect');
        // Finds the selected page in the BE exactly as in t3lib_SCbase::init().
        $rootline = $sys_page->getRootLine($pageId);

        // Generates the constants/config and hierarchy info for the template.
        $template->runThroughTemplates($rootline, 0);
        $template->generateConfig();

        if (isset($template->setup['plugin.']['tx_wfqbe_pi1.'])) {
            $result = $template->setup['plugin.']['tx_wfqbe_pi1.'];
        } else {
            $result = array();
        }

        $this->conf = $result;
    }


}


if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/wfqbe/lib/class.tx_wfqbe_api_query.php']) {
    include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/wfqbe/lib/class.tx_wfqbe_api_query.php']);
}

?>
